cordex.core.regions package
===========================

Submodules
----------

cordex.core.regions.germany module
----------------------------------

.. automodule:: cordex.core.regions.germany
   :members:
   :undoc-members:
   :show-inheritance:

cordex.core.regions.mask module
-------------------------------

.. automodule:: cordex.core.regions.mask
   :members:
   :undoc-members:
   :show-inheritance:

cordex.core.regions.prudence module
-----------------------------------

.. automodule:: cordex.core.regions.prudence
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cordex.core.regions
   :members:
   :undoc-members:
   :show-inheritance:
